@@ -9,9 +9,9 @@ use Exporter 'import';
 require String::Escape;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-14'; # DATE
+our $DATE = '2023-01-15'; # DATE
 our $DIST = 'Module-Release-Select'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our @EXPORT_OK = qw(
                        $RE
@@ -390,7 +390,9 @@ sub select_release {
     my $rels = shift;
 
     $opts->{single} = 1;
-    select_releases($opts, $expr, $rels);
+    my @rels = select_releases($opts, $expr, $rels);
+    return undef unless @rels; ## no critic: Subroutines::ProhibitExplicitReturnUndef
+    $rels[0];
 }
 
 1;
@@ -408,7 +410,7 @@ Module::Release::Select - Notation to select release(s)
 
 =head1 VERSION
 
-This document describes version 0.001 of Module::Release::Select (from Perl distribution Module-Release-Select), released on 2023-01-14.
+This document describes version 0.002 of Module::Release::Select (from Perl distribution Module-Release-Select), released on 2023-01-15.
 
 =head1 SYNOPSIS
 
